pub struct Status(/* private fields */);Expand description
The status register in PCI configuration space.
Implementations
Sourceimpl Status
impl Status
Sourcepub const INTERRUPT_STATUS: Status
pub const INTERRUPT_STATUS: Status
The state of the device’s INTx# signal.
Sourcepub const CAPABILITIES_LIST: Status
pub const CAPABILITIES_LIST: Status
The device has a linked list of capabilities.
Sourcepub const MHZ_66_CAPABLE: Status
pub const MHZ_66_CAPABLE: Status
The device is capabile of running at 66 MHz rather than 33 MHz.
Sourcepub const FAST_BACK_TO_BACK_CAPABLE: Status
pub const FAST_BACK_TO_BACK_CAPABLE: Status
The device can accept fast back-to-back transactions not from the same agent.
Sourcepub const MASTER_DATA_PARITY_ERROR: Status
pub const MASTER_DATA_PARITY_ERROR: Status
The bus agent observed a parity error (if parity error handling is enabled).
Sourcepub const SIGNALED_TARGET_ABORT: Status
pub const SIGNALED_TARGET_ABORT: Status
A target device terminated a transaction with target-abort.
Sourcepub const RECEIVED_TARGET_ABORT: Status
pub const RECEIVED_TARGET_ABORT: Status
A master device transaction was terminated with target-abort.
Sourcepub const RECEIVED_MASTER_ABORT: Status
pub const RECEIVED_MASTER_ABORT: Status
A master device transaction was terminated with master-abort.
Sourcepub const SIGNALED_SYSTEM_ERROR: Status
pub const SIGNALED_SYSTEM_ERROR: Status
A device asserts SERR#.
Sourcepub const DETECTED_PARITY_ERROR: Status
pub const DETECTED_PARITY_ERROR: Status
The device detects a parity error, even if parity error handling is disabled.
Sourceimpl Status
impl Status
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Status>
pub const fn from_bits(bits: u16) -> Option<Status>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Status
pub const fn from_bits_truncate(bits: u16) -> Status
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Status
pub const fn from_bits_retain(bits: u16) -> Status
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Status>
pub fn from_name(name: &str) -> Option<Status>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Status) -> bool
pub const fn intersects(&self, other: Status) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Status) -> bool
pub const fn contains(&self, other: Status) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Status)
pub fn remove(&mut self, other: Status)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Status)
pub fn toggle(&mut self, other: Status)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Status, value: bool)
pub fn set(&mut self, other: Status, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Status) -> Status
pub const fn intersection(self, other: Status) -> Status
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Status) -> Status
pub const fn union(self, other: Status) -> Status
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Status) -> Status
pub const fn difference(self, other: Status) -> Status
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Status) -> Status
pub const fn symmetric_difference(self, other: Status) -> Status
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Status
pub const fn complement(self) -> Status
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Status
impl Status
Sourcepub const fn iter(&self) -> Iter<Status>
pub const fn iter(&self) -> Iter<Status>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Status>
pub const fn iter_names(&self) -> IterNames<Status>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.